/*
 * msg.c
 *
 * This module supports the most common printouts on stdout with flushing.
 *
 * (C) Copyright 2002-2007, Axis Communications AB, LUND, SWEDEN
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include "msg.h"

/* Sends an informative message to stdout since boa does not connect stderr. */
void
msg(const char* message)
{
	fprintf(stdout, "%s\r\n", message);
	(void)fflush(stdout);
}

void
fdmsg(int fd, const char* message)
{
	write(fd, message, strlen(message));
	write(fd, "\r\n", 2);
}

void
msg_int(const char* message, unsigned int value)
{
	fprintf(stdout, "%s: [%u] [%08X]\r\n", message, value, value);
	(void)fflush(stdout);
}

/* Sends an error message to stdout since boa does not connect stderr. */
void
errmsg_errno(const char* message, int value)
{
	fprintf(stdout, "%s [%d] %s\r\n", message, value, strerror(value));
	(void)fflush(stdout);
}
